@@ -27,18 +27,16 @@
 #include "yaf_request.h"
 #include "yaf_exception.h"
 
+#if PHP_MAJOR_VERSION > 7
+#include "yaf_request_arginfo.h"
+#else
+#include "yaf_request_legacy_arginfo.h"
+#endif
+
 #include "requests/yaf_request_http.h"
 
 zend_class_entry *yaf_request_http_ce;
 
-/** {{{ ARG_INFO
- */
-ZEND_BEGIN_ARG_INFO_EX(yaf_request_http_arginfo, 0, 0, 0)
-ZEND_ARG_INFO(0, request_uri)
-ZEND_ARG_INFO(0, base_uri)
-ZEND_END_ARG_INFO()
-/* }}} */
-
 void yaf_request_http_init(yaf_request_object *req, zend_string *request_uri, zend_string *base_uri) /* {{{ */ {
 	const char *method;
 	zend_string *settled_uri = NULL;
@@ -152,7 +150,7 @@ PHP_METHOD(yaf_request_http, __construct) {
 /** {{{ yaf_request_http_methods
  */
 zend_function_entry yaf_request_http_methods[] = {
-	PHP_ME(yaf_request_http, __construct,      yaf_request_http_arginfo, ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
+	PHP_ME(yaf_request_http, __construct, arginfo_class_Yaf_Request_Http___construct, ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
 	{NULL, NULL, NULL}
 };
 /* }}} */
