@@ -22,36 +22,19 @@
 
 #include "php_yaf.h"
 #include "Zend/zend_interfaces.h" /* for zend_class_serialize_deny */
-
 #include "yaf_namespace.h"
+
+#if PHP_MAJOR_VERSION > 7
+#include "yaf_registry_arginfo.h"
+#else
+#include "yaf_registry_legacy_arginfo.h"
+#endif
+
 #include "yaf_registry.h"
 
 zend_class_entry    *yaf_registry_ce;
 static zend_object_handlers yaf_registry_obj_handlers;
 
-/* {{{ ARG_INFO
- */
-ZEND_BEGIN_ARG_INFO_EX(yaf_registry_void_arginfo, 0, 0, 0)
-ZEND_END_ARG_INFO()
-
-ZEND_BEGIN_ARG_INFO_EX(yaf_registry_get_arginfo, 0, 0, 1)
-	ZEND_ARG_INFO(0, name)
-ZEND_END_ARG_INFO()
-
-ZEND_BEGIN_ARG_INFO_EX(yaf_registry_has_arginfo, 0, 0, 1)
-	ZEND_ARG_INFO(0, name)
-ZEND_END_ARG_INFO()
-
-ZEND_BEGIN_ARG_INFO_EX(yaf_registry_del_arginfo, 0, 0, 1)
-	ZEND_ARG_INFO(0, name)
-ZEND_END_ARG_INFO()
-
-ZEND_BEGIN_ARG_INFO_EX(yaf_registry_set_arginfo, 0, 0, 2)
-	ZEND_ARG_INFO(0, name)
-	ZEND_ARG_INFO(0, value)
-ZEND_END_ARG_INFO()
-/* }}} */
-
 static HashTable *yaf_registry_get_properties(yaf_object *obj) /* {{{ */ {
     zval rv;
     HashTable *ht;
@@ -216,11 +199,11 @@ PHP_METHOD(yaf_registry, getInstance) {
 /** {{{ yaf_registry_methods
 */
 zend_function_entry yaf_registry_methods[] = {
-	PHP_ME(yaf_registry, __construct, 	yaf_registry_void_arginfo, ZEND_ACC_CTOR|ZEND_ACC_PRIVATE)
-	PHP_ME(yaf_registry, get, yaf_registry_get_arginfo, ZEND_ACC_PUBLIC|ZEND_ACC_STATIC)
-	PHP_ME(yaf_registry, has, yaf_registry_has_arginfo, ZEND_ACC_PUBLIC|ZEND_ACC_STATIC)
-	PHP_ME(yaf_registry, set, yaf_registry_set_arginfo, ZEND_ACC_PUBLIC|ZEND_ACC_STATIC)
-	PHP_ME(yaf_registry, del, yaf_registry_del_arginfo, ZEND_ACC_PUBLIC|ZEND_ACC_STATIC)
+	PHP_ME(yaf_registry, __construct, arginfo_class_Yaf_Registry___construct, ZEND_ACC_CTOR|ZEND_ACC_PRIVATE)
+	PHP_ME(yaf_registry, get, arginfo_class_Yaf_Registry_get, ZEND_ACC_PUBLIC|ZEND_ACC_STATIC)
+	PHP_ME(yaf_registry, has, arginfo_class_Yaf_Registry_has, ZEND_ACC_PUBLIC|ZEND_ACC_STATIC)
+	PHP_ME(yaf_registry, set, arginfo_class_Yaf_Registry_set, ZEND_ACC_PUBLIC|ZEND_ACC_STATIC)
+	PHP_ME(yaf_registry, del, arginfo_class_Yaf_Registry_del, ZEND_ACC_PUBLIC|ZEND_ACC_STATIC)
 	{NULL, NULL, NULL}
 };
 /* }}} */
@@ -233,9 +216,13 @@ YAF_STARTUP_FUNCTION(registry) {
 	YAF_INIT_CLASS_ENTRY(ce, "Yaf_Registry", "Yaf\\Registry", yaf_registry_methods);
 
 	yaf_registry_ce = zend_register_internal_class_ex(&ce, NULL);
+#if PHP_VERSION_ID < 80100
 	yaf_registry_ce->ce_flags |= ZEND_ACC_FINAL;
 	yaf_registry_ce->serialize = zend_class_serialize_deny;
 	yaf_registry_ce->unserialize = zend_class_unserialize_deny;
+#else
+	yaf_registry_ce->ce_flags |= ZEND_ACC_FINAL | ZEND_ACC_NOT_SERIALIZABLE;
+#endif
 
 	memcpy(&yaf_registry_obj_handlers, zend_get_std_object_handlers(), sizeof(zend_object_handlers));
 	yaf_registry_obj_handlers.offset = XtOffsetOf(yaf_registry_object, std);
